@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -25,9 +25,7 @@ class DescribeRegionsRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param Product: 待查询产品的名称，例如cvm、vpc
-        :type Product: str
-        """
+        :param Product: 待查询产品的名称，例如cvm、vpc\n        :type Product: str\n        """
         self.Product = None
 
 
@@ -38,7 +36,7 @@ class DescribeRegionsRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -49,13 +47,7 @@ class DescribeRegionsResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param TotalCount: 地域数量
-        :type TotalCount: int
-        :param RegionSet: 地域列表信息
-        :type RegionSet: list of RegionInfo
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
+        :param TotalCount: 地域数量\n        :type TotalCount: int\n        :param RegionSet: 地域列表信息\n        :type RegionSet: list of RegionInfo\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.TotalCount = None
         self.RegionSet = None
         self.RequestId = None
@@ -70,13 +62,6 @@ class DescribeRegionsResponse(AbstractModel):
                 obj._deserialize(item)
                 self.RegionSet.append(obj)
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class DescribeZonesRequest(AbstractModel):
@@ -86,9 +71,7 @@ class DescribeZonesRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param Product: 待查询产品的名称，例如cvm、vpc
-        :type Product: str
-        """
+        :param Product: 待查询产品的名称，例如cvm、vpc\n        :type Product: str\n        """
         self.Product = None
 
 
@@ -99,7 +82,7 @@ class DescribeZonesRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -110,13 +93,7 @@ class DescribeZonesResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param TotalCount: 可用区数量。
-        :type TotalCount: int
-        :param ZoneSet: 可用区列表信息。
-        :type ZoneSet: list of ZoneInfo
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
+        :param TotalCount: 可用区数量。\n        :type TotalCount: int\n        :param ZoneSet: 可用区列表信息。\n        :type ZoneSet: list of ZoneInfo\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.TotalCount = None
         self.ZoneSet = None
         self.RequestId = None
@@ -131,13 +108,6 @@ class DescribeZonesResponse(AbstractModel):
                 obj._deserialize(item)
                 self.ZoneSet.append(obj)
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class RegionInfo(AbstractModel):
@@ -147,13 +117,7 @@ class RegionInfo(AbstractModel):
 
     def __init__(self):
         """
-        :param Region: 地域名称，例如，ap-guangzhou
-        :type Region: str
-        :param RegionName: 地域描述，例如，华南地区(广州)
-        :type RegionName: str
-        :param RegionState: 地域是否可用状态
-        :type RegionState: str
-        """
+        :param Region: 地域名称，例如，ap-guangzhou\n        :type Region: str\n        :param RegionName: 地域描述，例如，华南地区(广州)\n        :type RegionName: str\n        :param RegionState: 地域是否可用状态\n        :type RegionState: str\n        """
         self.Region = None
         self.RegionName = None
         self.RegionState = None
@@ -168,7 +132,7 @@ class RegionInfo(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -223,15 +187,7 @@ class ZoneInfo(AbstractModel):
 <li> na-ashburn-1 </li>
 <li> na-ashburn-2 </li>
 <li> ap-nanjing-1 </li>
-<li> ap-nanjing-2 </li>
-        :type Zone: str
-        :param ZoneName: 可用区描述，例如，广州三区
-        :type ZoneName: str
-        :param ZoneId: 可用区ID
-        :type ZoneId: str
-        :param ZoneState: 可用区状态，包含AVAILABLE和UNAVAILABLE。AVAILABLE代表可用，UNAVAILABLE代表不可用。
-        :type ZoneState: str
-        """
+<li> ap-nanjing-2 </li>\n        :type Zone: str\n        :param ZoneName: 可用区描述，例如，广州三区\n        :type ZoneName: str\n        :param ZoneId: 可用区ID\n        :type ZoneId: str\n        :param ZoneState: 可用区状态，包含AVAILABLE和UNAVAILABLE。AVAILABLE代表可用，UNAVAILABLE代表不可用。\n        :type ZoneState: str\n        """
         self.Zone = None
         self.ZoneName = None
         self.ZoneId = None
@@ -248,5 +204,5 @@ class ZoneInfo(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
\ No newline at end of file
